@@ -3,6 +3,7 @@
 #
 import io
 import os
+from urllib.parse import urljoin
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
@@ -10,16 +11,10 @@ from django.core.files.base import File
 from django.core.files.storage import Storage
 from django.utils.deconstruct import deconstructible
 
-try:
-    from django.utils.six import string_types
-    from django.utils.six.moves.urllib.parse import urljoin
-except ImportError:
-    string_types = str
-    from urllib.parse import urljoin
-
 try:
     from libcloud.storage.providers import get_driver
-    from libcloud.storage.types import ObjectDoesNotExistError, Provider
+    from libcloud.storage.types import ObjectDoesNotExistError
+    from libcloud.storage.types import Provider
 except ImportError:
     raise ImproperlyConfigured("Could not load libcloud")
 
@@ -44,7 +39,7 @@ class LibCloudStorage(Storage):
             extra_kwargs['project'] = self.provider['project']
         try:
             provider_type = self.provider['type']
-            if isinstance(provider_type, string_types):
+            if isinstance(provider_type, str):
                 module_path, tag = provider_type.rsplit('.', 1)
                 if module_path != 'libcloud.storage.types.Provider':
                     raise ValueError("Invalid module path")
