@@ -1,22 +1,25 @@
 import mimetypes
-from datetime import datetime, timedelta
+from datetime import datetime
+from datetime import timedelta
 from tempfile import SpooledTemporaryFile
 
 from azure.core.exceptions import ResourceNotFoundError
-from azure.storage.blob import (
-    BlobClient, BlobSasPermissions, BlobServiceClient, ContentSettings,
-    generate_blob_sas,
-)
+from azure.storage.blob import BlobClient
+from azure.storage.blob import BlobSasPermissions
+from azure.storage.blob import BlobServiceClient
+from azure.storage.blob import ContentSettings
+from azure.storage.blob import generate_blob_sas
 from django.core.exceptions import SuspiciousOperation
 from django.core.files.base import File
 from django.utils import timezone
 from django.utils.deconstruct import deconstructible
-from django.utils.encoding import force_bytes
 
 from storages.base import BaseStorage
-from storages.utils import (
-    clean_name, get_available_overwrite_name, safe_join, setting,
-)
+from storages.utils import clean_name
+from storages.utils import get_available_overwrite_name
+from storages.utils import safe_join
+from storages.utils import setting
+from storages.utils import to_bytes
 
 
 @deconstructible
@@ -40,11 +43,9 @@ class AzureStorageFile(File):
             dir=setting("FILE_UPLOAD_TEMP_DIR", None))
 
         if 'r' in self._mode or 'a' in self._mode:
-            # I set max connection to 1 since spooledtempfile is
-            # not seekable which is required if we use max_connections > 1
             download_stream = self._storage.client.download_blob(
                 self._path, timeout=self._storage.timeout)
-            download_stream.download_to_stream(file, max_concurrency=1)
+            download_stream.readinto(file)
         if 'r' in self._mode:
             file.seek(0)
 
@@ -67,7 +68,7 @@ class AzureStorageFile(File):
                 'a' not in self._mode):
             raise AttributeError("File was not opened in write mode.")
         self._is_dirty = True
-        return super().write(force_bytes(content))
+        return super().write(to_bytes(content))
 
     def close(self):
         if self._file is None:
@@ -142,17 +143,20 @@ class AzureStorage(BaseStorage):
             "default_content_type": 'application/octet-stream',
             "cache_control": setting("AZURE_CACHE_CONTROL"),
             "sas_token": setting('AZURE_SAS_TOKEN'),
+            "endpoint_suffix": setting('AZURE_ENDPOINT_SUFFIX', 'core.windows.net'),
             "custom_domain": setting('AZURE_CUSTOM_DOMAIN'),
             "connection_string": setting('AZURE_CONNECTION_STRING'),
             "token_credential": setting('AZURE_TOKEN_CREDENTIAL'),
+            "api_version": setting('AZURE_API_VERSION', None),
         }
 
     def _get_service_client(self):
         if self.connection_string is not None:
             return BlobServiceClient.from_connection_string(self.connection_string)
 
-        account_domain = self.custom_domain or "{}.blob.core.windows.net".format(
-            self.account_name
+        account_domain = self.custom_domain or "{}.blob.{}".format(
+            self.account_name,
+            self.endpoint_suffix,
         )
         account_url = "{}://{}".format(self.azure_protocol, account_domain)
 
@@ -166,7 +170,10 @@ class AzureStorage(BaseStorage):
             credential = self.sas_token
         elif self.token_credential:
             credential = self.token_credential
-        return BlobServiceClient(account_url, credential=credential)
+        options = {}
+        if self.api_version:
+            options["api_version"] = self.api_version
+        return BlobServiceClient(account_url, credential=credential, **options)
 
     @property
     def service_client(self):
@@ -335,9 +342,8 @@ class AzureStorage(BaseStorage):
         Returns an (aware) datetime object containing the last modified time if
         USE_TZ is True, otherwise returns a naive datetime in the local timezone.
         """
-        properties = self.client.get_blob_properties(
-            self._get_valid_path(name),
-            timeout=self.timeout)
+        blob_client = self.client.get_blob_client(self._get_valid_path(name))
+        properties = blob_client.get_blob_properties(timeout=self.timeout)
         if not setting('USE_TZ', False):
             return timezone.make_naive(properties.last_modified)
 
