@@ -3,17 +3,21 @@ import pickle
 import threading
 from datetime import datetime
 from textwrap import dedent
-from unittest import mock, skipIf
+from unittest import mock
+from unittest import skipIf
 from urllib.parse import urlparse
 
 from botocore.exceptions import ClientError
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.base import ContentFile
-from django.test import TestCase, override_settings
-from django.utils.timezone import is_aware, utc
+from django.test import TestCase
+from django.test import override_settings
+from django.utils.timezone import is_aware
+from django.utils.timezone import utc
 
 from storages.backends import s3boto3
+from tests.utils import NonSeekableContentFile
 
 
 class S3ManifestStaticStorageTestStorage(s3boto3.S3ManifestStaticStorage):
@@ -21,18 +25,6 @@ class S3ManifestStaticStorageTestStorage(s3boto3.S3ManifestStaticStorage):
         return None
 
 
-class NonSeekableContentFile(ContentFile):
-
-    def open(self, mode=None):
-        return self
-
-    def seekable(self):
-        return False
-
-    def seek(self, pos, whence=0):
-        raise AttributeError()
-
-
 class S3Boto3StorageTests(TestCase):
     def setUp(self):
         self.storage = s3boto3.S3Boto3Storage()
@@ -132,7 +124,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'text/plain',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_non_seekable(self):
@@ -149,7 +142,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'text/plain',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_with_default_acl(self):
@@ -168,7 +162,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/plain',
                 'ACL': 'private',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_object_parameters_not_overwritten_by_default(self):
@@ -188,7 +183,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/plain',
                 'ACL': 'private',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_content_type(self):
@@ -206,7 +202,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'image/jpeg',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzipped(self):
@@ -222,7 +219,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'application/octet-stream',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzipped_non_seekable(self):
@@ -238,7 +236,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'application/octet-stream',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzip(self):
@@ -255,7 +254,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/css',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
         args, kwargs = obj.upload_fileobj.call_args
         content = args[0]
@@ -282,7 +282,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/css',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
         args, kwargs = obj.upload_fileobj.call_args
         content = args[0]
